package dev.lonami.talaria.ui.state

import androidx.lifecycle.ViewModel
import dev.lonami.talaria.data.MessageRepository
import dev.lonami.talaria.models.Message
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.flow.update

class ChatViewModel : ViewModel() {
    private val _uiState = MutableStateFlow(ChatUiState())
    val uiState: StateFlow<ChatUiState> = _uiState.asStateFlow()

    private fun loadMessages() {
        _uiState.value = ChatUiState(MessageRepository.loadMessages().toMutableList())
    }

    fun sendMessage(dialog: String, message: String) {
        sendMessage(dialog, message)
        _uiState.update { state ->
            state.messages.add(Message("You", message))
            state
        }
    }

    init {
        loadMessages()
    }
}
